@@ -148,11 +148,12 @@ class KubeModel(ABC):
         Saves the optimizer state to be loaded again in
         the following epochs
         """
-        
+        job_id = self.args._job_id
+        func_id = self.args._func_id
         self.logger.debug('saving file to host')
 
-        with open('/output/{job_id}:test:{func_id}.pkl', 'wb') as f:
-            self.logger.debug('saving file, epoch: {self.epoch}')
+        with open(f'/output/{job_id}:test:{func_id}.pkl', 'wb') as f:
+            self.logger.debug(f'saving file, epoch: {self.epoch}')
             pickle.dump('test', f)
             self.logger.debug('file saved')
         print('file saved')   
@@ -162,13 +163,14 @@ class KubeModel(ABC):
         Saves the optimizer state to be loaded again in
         the following epochs
         """
-        
+        job_id = self.args._job_id
+        func_id = self.args._func_id
         self.logger.debug('loading file to host')
 
-        with open('/output/{job_id}:test:{func_id}.pkl', 'wb') as f:
-            self.logger.debug('loading file, epoch: {self.epoch}')
+        with open(f'/output/{job_id}:test:{func_id}.pkl', 'wb') as f:
+            self.logger.debug(f'loading file, epoch: {self.epoch}')
             state = pickle.load(f)
-            self.logger.debug('file loaded, value: {state}')
+            self.logger.debug(f'file loaded, value: {state}')
             print('file loaded')    
 
     def _save_optimizer_redis(self):
@@ -325,7 +327,7 @@ class KubeModel(ABC):
         self.__load_model()
         self._load_optimizer_redis()
         self._load_redis_test()
-        self._load_file_test()
+        #self._load_file_test()
 
         #self._load_optimizer_state()
 
@@ -339,7 +341,7 @@ class KubeModel(ABC):
         self.__save_model()
         self._save_optimizer_redis()
         self._save_redis_test()
-        self._save_file_test()
+        #self._save_file_test()
         #self._save_optimizer_state()
 
     def _batch_to_device(self, batch: Union[torch.Tensor, Iterable[torch.Tensor]]):
